==> compat-el_29.1.3.1+dfsg.orig.tar.gz: compat-el-29.1.3.1+dfsg/README.md <==
COMPATibility Library for Emacs
===============================
Find here the source for compat.el, a forwards-compatibility library for (GNU)
Emacs Lisp, versions 24.4 and newer. The intended audience are package
developers that are interested in using newer developments, without having to
break compatibility.

For information on how to use Compat, please consult the [manual]. The latest
state of development can be found in the [snapshot version].

[manual]:
    https://elpa.gnu.org/packages/doc/compat.html
[snapshot version]:
    https://elpa.gnu.org/devel/doc/compat.html


Source code
-----------
Compat is developed on [GitHub]. The code is mirrored to the [GNU ELPA
repository].

[GitHub]:
    https://github.com/emacs-compat/compat
[GNU ELPA repository]:
    https://git.savannah.gnu.org/cgit/emacs/elpa.git/tree/?h=externals/compat


Bug and patches
---------------
Patches, bug reports and comments can be sent via [GitHub]. These may include
issues in the compatibility code, missing definitions or performance issues. We
also provide a [development mailing list].

[development mailing list]:
    https://lists.sr.ht/~pkal/compat-devel


Contribute
----------
As compat.el is distribed as part of [GNU ELPA], and therefore requires a
[copyright assignment] to the [FSF], for all non-trivial code contributions.

[GNU ELPA]:
    http://elpa.gnu.org/packages/compat.html
[copyright assignment]:
    https://www.gnu.org/software/emacs/manual/html_node/emacs/Copyright-Assignment.html
[FSF]:
    https://www.fsf.org/


Distribution
------------
compat.el and all other source files in this directory are distributed under the
[GNU Public License 3] like Emacs itself. The manual is distributed under the
[GNU Free Documentation License 1.3].

[GNU Public License 3]:
    https://www.gnu.org/licenses/gpl-3.0.en.html
[GNU Free Documentation License 1.3]:
    https://www.gnu.org/licenses/fdl-1.3.html

==> compat-el_29.1.3.4+dfsg.orig.tar.gz: compat-el-29.1.3.4+dfsg/README.md <==
COMPATibility Library for Emacs
===============================
This is the source of compat.el, the forwards-compatibility library for (GNU)
Emacs Lisp, versions 24.4 and newer. The intended audience are package
developers that are interested in using newer developments, without having to
break compatibility.

For information on how to use Compat, please consult the [manual]. The latest
state of development can be found in the [snapshot version] of the manual.

[manual]:
    https://elpa.gnu.org/packages/doc/compat.html
[snapshot version]:
    https://elpa.gnu.org/devel/doc/compat.html


Source code
-----------
Compat is developed on [GitHub]. The code is mirrored to the [GNU ELPA
repository], which is the canonical repository for the [GNU ELPA package
builds].

[GitHub]:
    https://github.com/emacs-compat/compat
[GNU ELPA repository]:
    https://git.savannah.gnu.org/cgit/emacs/elpa.git/tree/?h=externals/compat
[GNU ELPA package builds]:
    http://elpa.gnu.org/packages/compat.html

Bug and patches
---------------
Patches, bug reports and comments can be sent via [GitHub]. These may include
issues in the compatibility code, missing definitions or performance issues. We
also provide a [development mailing list].

[development mailing list]:
    https://lists.sr.ht/~pkal/compat-devel


Contribute
----------
As compat.el is distributed as part of [GNU ELPA], and therefore requires a
[copyright assignment] to the [FSF], for all non-trivial code contributions.

[GNU ELPA]:
    http://elpa.gnu.org/packages/compat.html
[copyright assignment]:
    https://www.gnu.org/software/emacs/manual/html_node/emacs/Copyright-Assignment.html
[FSF]:
    https://www.fsf.org/


Distribution
------------
compat.el and all other source files in this directory are distributed under the
[GNU Public License 3] like Emacs itself. The manual is distributed under the
[GNU Free Documentation License 1.3].

[GNU Public License 3]:
    https://www.gnu.org/licenses/gpl-3.0.en.html
[GNU Free Documentation License 1.3]:
    https://www.gnu.org/licenses/fdl-1.3.html
